<u><h1>ez save- an simple lib to save data in python</h1></u>
<p>
this is a lib which helps save data to files easily with basic encryption.
it's nothing complex and more of a learning project for me.
<br>
docs: https://github.com/tbubhnh/ez_save/blob/master/docs/docs.md<br>
examples: https://github.com/tbubhnh/ez_save/tree/master/examples
</p>
<u><b>installation</b></u>
<p>


```
pip install ezsave
```
</p>
